from django.utils.translation import ugettext_lazy as _
from rest_framework.serializers import ValidationError


class APIError(ValidationError):
    MISSING_USER = {'code': 'missing-user', 'msg': _('an user must be specified')}
    UNKNOWN_USER = {'code': 'unknown-user', 'msg': _('user is unknown')}
    TOO_MANY_USERS = {'code': 'too-many-users', 'msg': _('too many users have this email')}
    NOT_BASE64 = {'code': 'not-base64', 'msg': _('data is not base64 encoded')}
    NOT_STRING = {'code': 'not-string', 'msg': _('data is not a string')}
    TOO_BIG = {'code': 'too-big', 'msg': _('file is too big (limit is {limit})')}
    BOX_IS_FULL = {'code': 'box-is-full', 'msg': _('box is full (limit is {limit})')}
    DOCUMENT_EXISTS = {'code': 'document-exists', 'msg': _('user already have this document')}

    def __init__(self, kind, **kwargs):
        assert hasattr(self, kind), 'error %s is not defined' % kind

        detail = getattr(self, kind).copy()
        detail.update(kwargs)
        detail['msg'] = detail['msg'].format(**kwargs)
        super(APIError, self).__init__([detail])
