from django import forms
from django.utils.translation import ugettext_lazy as _
from django.conf import settings
from django.template.defaultfilters import filesizeformat


from . import models


class UploadForm(forms.ModelForm):
    content = forms.FileField(
        label=_('file'), max_length=512)

    def clean_content(self):
        content = self.cleaned_data.get('content')
        if content:
            if content.size > settings.FARGO_MAX_DOCUMENT_SIZE:
                raise forms.ValidationError(_('Uploaded file is too big (limit is %s)') %
                                            filesizeformat(settings.FARGO_MAX_DOCUMENT_SIZE))
        return content

    def clean(self):
        content = self.cleaned_data.get('content')
        if content:
            if (models.Document.objects.used_space(self.instance.user) + content.size
                    > settings.FARGO_MAX_DOCUMENT_BOX_SIZE):
                raise forms.ValidationError(_('Your document box is full (limit is %s)') %
                                            settings.FARGO_MAX_DOCUMENT_BOX_SIZE)
        return self.cleaned_data

    def save(self, *args, **kwargs):
        self.instance.filename = self.files['content'].name[:512]
        self.instance.document = models.Document.objects.get_by_file(
            self.files['content'])
        return super(UploadForm, self).save(*args, **kwargs)

    class Meta:
        model = models.UserDocument
        fields = []


class EditForm(forms.ModelForm):
    class Meta:
        model = models.UserDocument
        fields = ['title', 'description', 'expiration_date']
        widgets = {
            'expiration_date': forms.TextInput(attrs={'type': 'date'})
        }
