import hashlib

from django.utils.timezone import utc
from django.utils.encoding import smart_bytes
from django.apps import apps

try:
    import magic
except ImportError:
    magic = None


def to_isodate(dt):
    return dt.astimezone(utc).isoformat('T').split('.')[0] + 'Z'


def get_document_type_schema(settings, document_type):
    for schema in settings.FARGO_DOCUMENT_TYPES:
        if schema.get('name') == document_type:
            return schema


def sha256_of_file(f):
    '''Compute SHA-256 hash of Django File object'''
    hasher = hashlib.sha256()
    for chunk in f.chunks():
        hasher.update(chunk)
    return hasher.hexdigest()


def get_mime_type(path):
    if magic is None:
        return None

    magic_object = magic.open(magic.MIME)
    magic_object.load()
    mime_type = magic_object.file(smart_bytes(path))
    magic_object.close()
    if mime_type:
        mime_type = mime_type.split(';')[0]
        if mime_type.startswith('cannot open'):
            mime_type = None
    return mime_type


def cleanup_model(model, n=None):
    manager = getattr(model, 'objects', None)
    if hasattr(manager, 'cleanup'):
        manager.cleanup(n=n)


def cleanup(n=None):
    for model in apps.get_models():
        cleanup_model(model, n=n)
